@@ -1,12 +1,17 @@
 package WordList;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-02'; # DATE
+our $DATE = '2020-05-04'; # DATE
 our $DIST = 'WordList'; # DIST
-our $VERSION = '0.5.2'; # VERSION
+our $VERSION = '0.5.3'; # VERSION
 
 use strict 'subs', 'vars';
 
+# IFUNBUILT
+# use Role::Tiny::With;
+# with 'WordListRole::WordList';
+# END IFUNBUILT
+
 sub new {
     my $class = shift;
     my $fh = \*{"$class\::DATA"};
@@ -136,7 +141,7 @@ WordList - Word lists
 
 =head1 VERSION
 
-This document describes version 0.5.2 of WordList (from Perl distribution WordList), released on 2020-05-02.
+This document describes version 0.5.3 of WordList (from Perl distribution WordList), released on 2020-05-04.
 
 =head1 SYNOPSIS
 
@@ -172,10 +177,13 @@ There must not be any duplicate entry in the word list.
 B<Dynamic and non-deterministic wordlist.> A dynamic wordlist must set package
 variable C<$DYNAMIC> to either 1 (deterministic) or 2 (non-deterministic). A
 dynamic wordlist does not put the wordlist in the DATA section; instead, user
-relies on C<each_word()> or C<all_words()> to get the list. A deterministic
-wordlist returns the same list everytime C<each_word()> or C<all_words()> is
-called. A non-deterministic list can return a different list for a different
-C<each_word()> or C<all_words()> call.
+relies on C<first_word()> + C<next_word()>, or C<each_word()>, or C<all_words()>
+to get the list. A deterministic wordlist returns the same list everytime
+C<each_word()> or C<all_words()> is called. A non-deterministic list can return
+a different list for a different C<each_word()> or C<all_words()> call. See
+L<WordListRole::Dynamic::FirstNextResetFromEach> and
+L<WordListRole::Dynamic::EachFromFirstNextReset> if you want to write a dynamic
+wordlist module.
 
 =head1 DIFFERENCES WITH GAMES::WORD::WORDLIST
 
